@@ -9,7 +9,7 @@ from datetime import datetime
 class Regbot:
   reg_model_path = resource_filename(__name__, 'finalized_model.h5') 
   model_scaler_path = resource_filename(__name__, 'logscaler.gz') 
-
+  thr = 0.5048710627477806 # remember to change this value for every model
 
   def __init__(self,*args):
   	pass
@@ -27,14 +27,19 @@ class Regbot:
       date = datetime.fromisoformat(utcdatetime)
       day = date.isoweekday()
       return day
+  
+  @classmethod
+  def getUtcHour(cls, utcdatetime):
+      utchour = int(str(utcdatetime).split(' ')[1].split(':')[0])
+      return utchour
 
   @classmethod  
-  def prepareInput(cls,opening,closing,utctime):
+  def prepareInput(cls,opening,closing,utcdatetime):
     avr = closing/(opening + closing)
     bvr = opening/(opening + closing)
-    time = int(str(utctime).split(' ')[1].split(':')[0])
-    day = cls.getWeekDay(utctime)  
-    testdata = np.array([[avr,bvr,time,day]])
+    day = cls.getWeekDay(utcdatetime)
+    time = cls.getUtcHour(utcdatetime)  
+    testdata = np.array([[avr,bvr,day,time]])
     with warnings.catch_warnings():
       warnings.filterwarnings("ignore")
       scaler = joblib.load(f'{cls.model_scaler_path}')
@@ -44,36 +49,35 @@ class Regbot:
 
 
   @classmethod
-  def buySignalGenerator(cls,opening,closing,utctime,sect):
-    scalledInput = cls.prepareInput(opening,closing,utctime)
+  def shortSignalGenerator(cls,opening,closing,utcdatetime):
+    scalledInput = cls.prepareInput(opening,closing,utcdatetime)
     with warnings.catch_warnings():
       warnings.filterwarnings("ignore")
-      return (cls.loadmodel().predict_proba(scalledInput)[:,1] > sect).astype(int)[0]
+      return (cls.loadmodel().predict_proba(scalledInput)[:,1] > cls.thr).astype(int)[0]
     
   @classmethod
-  def sellSignalGenerator(cls,opening,closing,utctime,sect):
+  def longSignalGenerator(cls,opening,closing,utctime):
     scalledInput = cls.prepareInput(opening,closing,utctime)
     with warnings.catch_warnings():
       warnings.filterwarnings("ignore")
-      return (cls.loadmodel().predict_proba(scalledInput)[:,1] <= sect).astype(int)[0]
+      return (cls.loadmodel().predict_proba(scalledInput)[:,1] <= cls.thr).astype(int)[0]
 
 
 
 
 def signal(opening: float,
           closing: float,
-          utctime: str,
-          dir: str,
-          sect: float
+          utcdatetime: str,
+          dir: str
           ):
   if dir == 'long':
     try:
-      return Regbot.buySignalGenerator(opening,closing,utctime,sect)
+      return Regbot.longSignalGenerator(opening,closing,utcdatetime)
     except Exception as e:
       print(e)
   if dir == 'short':
     try:
-      return Regbot.sellSignalGenerator(opening,closing,utctime,sect)
+      return Regbot.shortSignalGenerator(opening,closing,utcdatetime)
     except Exception as e:
       print(e)
   else:
